#!/bin/sh


log_file="/home/log/sys.log"
LOG_TRACE()
{
    echo "`date +'%Y-%m-%d %H:%M:%S'`: [TRACE] ${1}" >> $log_file
}
LOG_DEBUG()
{
    echo "`date +'%Y-%m-%d %H:%M:%S'`: [DEBUG] ${1}" >> $log_file
}
LOG_INFO()
{
    echo "`date +'%Y-%m-%d %H:%M:%S'`: [INFO] ${1}" >> $log_file
}
LOG_WARN()
{
    echo "`date +'%Y-%m-%d %H:%M:%S'`: [WARN] ${1}" >> $log_file
}
LOG_ERROR()
{
    echo "`date +'%Y-%m-%d %H:%M:%S'`: [ERROR] ${1}" >> $log_file
}
LOG_TO_LINES()
{
    log_temp="/home/log/temp"
    tail -${1} $log_file > $log_temp && mv &log_temp &log_file
}

start()
{
    mkdir -p /home/root
    mkdir -p /var/log
    /usr/sbin/dropbear
    swapon /swapfile
    if [ $? -eq 0 ]
    then
        /bin/mount -t tmpfs -o size=45M tmpfs /tmp
    fi


    if [ -f "/etc/TZSET" ];
    then
	LOG_INFO "source /etc/TZSET: '$(cat /etc/TZSET)'"
	source /etc/TZSET
    fi

    LOG_INFO "System started."

    LOG_INFO "Run RtcInit..."
    cd /etc/init.d
    chmod +x RtcInit

    count=0     #retry times
    while [ 0 -eq 0 ]
    do
        LOG_DEBUG "Start RtcInit..."
        ./RtcInit >> $log_file

        # check
        if [ $? -eq 0 ]; then     
            LOG_INFO "RtcInit success."
            break;
        else
            LOG_WARN "RtcInit wrong..."
            let count++
            if [ ${count} -eq 6 ]; then     
                LOG_ERROR "RtcInit error (> 5times)!"
                break
            fi
            LOG_INFO "retry(RtcInit) in 2 seconds"
            sleep 2
        fi
    done

    LOG_INFO "copy stdout-stderr.log start..."
    # mkdir -p /mnt/UDISK
    # mount /dev/mmcblk0p6 /mnt/UDISK
    sleep 1
    mv /mnt/UDISK/stdout-stderr-9.log /mnt/UDISK/stdout-stderr-10.log
    mv /mnt/UDISK/stdout-stderr-8.log /mnt/UDISK/stdout-stderr-9.log
    mv /mnt/UDISK/stdout-stderr-7.log /mnt/UDISK/stdout-stderr-8.log
    mv /mnt/UDISK/stdout-stderr-6.log /mnt/UDISK/stdout-stderr-7.log
    mv /mnt/UDISK/stdout-stderr-5.log /mnt/UDISK/stdout-stderr-6.log
    mv /mnt/UDISK/stdout-stderr-4.log /mnt/UDISK/stdout-stderr-5.log
    mv /mnt/UDISK/stdout-stderr-3.log /mnt/UDISK/stdout-stderr-4.log
    mv /mnt/UDISK/stdout-stderr-2.log /mnt/UDISK/stdout-stderr-3.log
    mv /mnt/UDISK/stdout-stderr-1.log /mnt/UDISK/stdout-stderr-2.log
    mv /home/root/stdout-stderr.log /mnt/UDISK/stdout-stderr-1.log
    LOG_INFO "copy stdout-stderr.log done..."

    LOG_INFO "Start autossh"
    cd /etc/init.d
    chmod +x ./devops.sh
    ./devops.sh &
    LOG_INFO "autossh started."

    chmod +x ./monitorLog.sh
    ./monitorLog.sh &

    chmod +x /usr/bin/monitorUpdate.sh
    /usr/bin/monitorUpdate.sh >> /home/log/sys.log 2>&1 &

    LOG_INFO "Start APP."

    cd /home/root/APP
    chmod 777 ./ecp5_rd_id
    a=$(cat /home/Param/CAMERA_DEPTH_UNIT) 
    b=$(cat /home/Param/binType)
    echo "$a" >> $log_file
    echo "$b" >> $log_file
    if [ $a == 3 ]
    then
	if [ $b == 0 ]
	then
            ./ecp5_rd_id imp_base_36_6.bin
	else
	    ./ecp5_rd_id imp_base_25_1280.bin
        fi
    else
        ./ecp5_rd_id imp_base_25.bin
    fi

    if [ $(ip route list | grep -c "default") -eq 2 ] 
    then
      default1=$(ip route list | grep default | grep eth0)
      default2=$(ip route list | grep default | grep wlan0)
      scope1=$(ip route list | grep scope| grep eth0)
      scope2=$(ip route list | grep scope| grep wlan0)
      ip1=${scope1#*src}
      ip2=${scope2#*src}

      echo $default1
      echo $default2
      echo $scope1
      echo $scope2
      echo $ip1
      echo $ip2

      cmd="ip route add to ${scope1} table 20"
      echo $cmd
      ${cmd}
      
      cmd="ip route add ${default1} table 20"
      echo $cmd
      ${cmd}

      cmd="ip rule add from ${ip1} table 20"
      echo $cmd
      ${cmd}

      cmd="ip route add to ${scope2} table 21"
      echo $cmd
      ${cmd}

      cmd="ip route add ${default2} table 21"
      echo $cmd
      ${cmd}

      cmd="ip rule add from ${ip2} table 21"
      echo $cmd
      ${cmd}
    fi

    cd /home/root/
    chmod 777 ./*
    ./startup &

    cd /etc/init.d
    sleep 25
    chmod +x ./scanip
    ./scanip &
    
    chmod +x monitor_services.sh
    ./monitor_services.sh &
    
    LOG_INFO "APP started."

    sync
}

stop()
{
    killall PassengerFlow watchDog sample_rtsp
    sleep 1
    printf "stop app\n"
    sync
}

case "$1" in
    start)
        start
        ;;
    stop)
        stop
        ;;
    restart|reload)
        stop
        start
        ;;
  *)
        echo "Usage: $0 {start|stop|restart}"
        exit 1
esac

exit $?
